#include "obgtkAccelLabel.h"

@implementation Gtk_AccelLabel
- castGtkAccelLabel:(GtkAccelLabel *) castitem
{
  gtkaccellabel = castitem;
  return [super castGtkLabel:GTK_LABEL(castitem)];
}

- init
{
  return [self initWithLabel:""];
}

- initWithLabel:(gchar *) str
{
  return [self castGtkAccelLabel:GTK_ACCEL_LABEL(gtk_accel_label_new(str))];
}

- (guint) get_accelerator_width
{
  return gtk_accel_label_get_accel_width(gtkaccellabel);
}

- set_accel_widget:(id) accel_widget
{
  gtk_accel_label_set_accel_widget(gtkaccellabel, ((Gtk_Widget *)accel_widget)->gtkwidget);
  return self;
}

- (gboolean) refetch
{
  return gtk_accel_label_refetch(gtkaccellabel);
}
@end
